@@ -62,7 +62,7 @@ in this Software without prior written authorization from the X Consortium.
  *  SOFTWARE.                                                                *
  * ***************************************************************************
  */
-/* $XFree86: test/xsuite/xtest/src/libproto/Expect.c,v 1.4 1997/05/17 11:36:41 dawes Exp $ */
+/* $XFree86: test/xsuite/xtest/src/libproto/Expect.c,v 1.5 2004/01/01 21:47:10 dawes Exp $ */
 
 #include "XstlibInt.h"
 
@@ -70,12 +70,6 @@ in this Software without prior written authorization from the X Consortium.
 	int *countp = (Get_Test_Type(cl)==SETUP)?(&Xst_delete_count):(&Xst_error_count);\
 	if (*countp>0) (*countp)--; } while (0)
 
-extern int  errno;
-extern int  sys_nerr;
-#if !defined(CSRG_BASED) && !defined(linux)
-extern char *sys_errlist[];
-#endif
-
 static int  max_extra = IBUFSIZE - sizeof (xReply);
 static char rbuf[IBUFSIZE];
 static char *rbp;
@@ -506,12 +500,7 @@ unsigned long   size;
 	    continue;
 	}
 	else {
-	    if ((errno >= 0) && (errno < sys_nerr)) {
-		(void) strcpy (emsg, sys_errlist[errno]);
-	    }
-	    else {
-		sprintf (emsg, "UNKNOWN ERROR - %d", errno);
-	    }
+	    strcpy (emsg, strerror(errno));
 	    Log_Msg ("Expect: wanted %s, got SYSTEM ERROR - %s\n", wanted, emsg);
 	    Finish (client);
 	}
